@@ -17,6 +17,7 @@ from itsimodels.core.setup_logging import logger
 
 
 KEY_FIELD_NAME = 'key'
+TITLE_FIELD_NAME = 'title'
 
 
 class ValidationError(Exception):
@@ -82,6 +83,9 @@ class BaseModel(object):
         if auto_validate:
             self.validate()
 
+    def get_title(self):
+        return getattr(self, TITLE_FIELD_NAME, None)
+
     def get_key(self):
         return getattr(self, KEY_FIELD_NAME, None)
 
@@ -192,7 +196,7 @@ class BaseModel(object):
                 value = field_decoder.decode(field_name, field, data)
 
                 if value is None and default is not None:
-                    if isinstance(default, collections.Callable):
+                    if isinstance(default, collections.abc.Callable):
                         value = default()
                     else:
                         value = copy.deepcopy(default)
