@@ -1,10 +1,14 @@
 import os
 import logging, logging.handlers
 from itsimodels import __version__
-#import splunk
 
+# Keeping this check for scenarios when itsicli is not found. Currently, itsicli is shipped in ITSI along with itsimodels 
+try:
+    from itsicli.setup_logging import extra
+except:
+    extra = {'cp_id': 'unknown'}
 
-LOG_DEFAULT_FMT = '%(asctime)s process:%(process)d thread:%(threadName)s %(levelname)s [%(name)s] [%(module)s:%(lineno)d] [%(funcName)s] %(message)s'
+LOG_DEFAULT_FMT = '%(asctime)s process:%(process)d thread:%(threadName)s %(levelname)s [cp_id: %(cp_id)s] [%(name)s] [%(module)s:%(lineno)d] [%(funcName)s] %(message)s'
 ITSI_MODELS_LOGGER = 'itsimodels'
 ITSI_MODELS_LOG_FILE = 'itsi_content_packs_itsimodels.log'
 
@@ -112,17 +116,19 @@ def setup_logging():
 
     _logger = logging.getLogger(ITSI_MODELS_LOGGER)
 
-    splunk_log_handler = logging.handlers.RotatingFileHandler(LOGGING_FILE_NAME, maxBytes=2500000, backupCount=5)
-    splunk_log_handler.setFormatter(logging.Formatter(LOG_DEFAULT_FMT))
-    _logger.addHandler(splunk_log_handler)
+    if not _logger.hasHandlers():
+        splunk_log_handler = logging.handlers.RotatingFileHandler(LOGGING_FILE_NAME, maxBytes=2500000, backupCount=5)
+        splunk_log_handler.setFormatter(logging.Formatter(LOG_DEFAULT_FMT))
+        _logger.addHandler(splunk_log_handler)
+        _logger = logging.LoggerAdapter(_logger, extra)
 
-    if SPLUNK_HOME is not None:
-        # splunk.setupSplunkLogger
-        setupSplunkLogger(_logger, LOGGING_DEFAULT_CONFIG_FILE, LOGGING_LOCAL_CONFIG_FILE, LOGGING_STANZA_NAME)
+        if SPLUNK_HOME is not None:
+            # splunk.setupSplunkLogger
+            setupSplunkLogger(_logger, LOGGING_DEFAULT_CONFIG_FILE, LOGGING_LOCAL_CONFIG_FILE, LOGGING_STANZA_NAME)
 
-    _logger.setLevel(logging.INFO)
+        _logger.setLevel(logging.INFO)
 
-    _logger.info('itsimodels version={} logger configured. LOGGING_FILE_NAME={}'.format(__version__,
+        _logger.debug('itsimodels version={} logger configured. LOGGING_FILE_NAME={}'.format(__version__,
                                                                                   LOGGING_FILE_NAME))
     return _logger
 
