@@ -6,3 +6,6 @@ class CorrelationSearch(DynamicModel):
     key = StringField(required=True)
 
     name = StringField(required=True)
+
+    def get_title(self):
+        return getattr(self, 'name')
