@@ -4,12 +4,12 @@ from itsimodels.core.base_models import (
 )
 from itsimodels.core.compat import string_types
 from itsimodels.core.fields import (
-    BoolField,
     DictField,
     ListField,
     StringField,
-    TypeField
+    TypeField, NumberField, ForeignKeyMultiEmbeddedStr
 )
+from itsimodels.service import GENERIC_SEARCH_RE
 
 
 class DataDrilldown(ChildModel):
@@ -37,17 +37,15 @@ class DashboardDrilldown(ChildModel):
 
     base_url = StringField(default='')
 
-    is_splunk_dashboard = BoolField(default=False)
-
     params = TypeField(DashboardDrilldownParams)
 
 
 class VitalMetric(ChildModel):
     metric_name = StringField(required=True)
 
-    search = StringField(required=True)
+    search = ForeignKeyMultiEmbeddedStr(refers=None, key_regex=GENERIC_SEARCH_RE)
 
-    is_key = BoolField(default=False)
+    is_key = NumberField(default=0)
 
     matching_entity_fields = ListField(string_types)
 
